@@ -1,5 +1,5 @@
 #
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -27,7 +27,7 @@ def example():
         print('Usage: ', sys.argv[0], ' file', file=sys.stderr)
         sys.exit(1)
 
-    f = open(sys.argv[1])
+    f = open(sys.argv[1], 'rb')
     while 1:
         ident = codes_grib_new_from_file(f)
         if ident is None:
