@@ -1,4 +1,4 @@
-# Copyright 2005-2017 ECMWF.
+# Copyright 2005-2018 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,9 +8,9 @@
 # nor does it submit to any jurisdiction.
 
 #
-# Python implementation: bufr_get_keys
+# Python implementation: gts_get_keys
 #
-# Description: how to read values of different type of keys from BUFR messages.
+# Description: how to read values of different type of keys from GTS messages.
 #
 #
 
@@ -25,8 +25,8 @@ VERBOSE = 1  # verbose error reporting
 
 
 def example():
-    # open bufr file
-    f = open(INPUT)
+    # open GTS file
+    f = open(INPUT, 'rb')
 
     cnt = 0
 
