@@ -146,7 +146,7 @@ static int destroy(grib_dumper* d)
 
 static char* lval_to_string(grib_context* c, long v)
 {
-    char* sval=grib_context_malloc_clear(c,sizeof(char)*40);
+    char* sval=(char*)grib_context_malloc_clear(c,sizeof(char)*40);
     if (v == GRIB_MISSING_LONG) sprintf(sval,"CODES_MISSING_LONG");
     else                        sprintf(sval,"%ld",v);
     return sval;
@@ -191,7 +191,7 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
         fprintf(self->dumper.out,"  free(rvalues); rvalues = NULL;\n\n");
         fprintf(self->dumper.out,"  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out,"  rvalues = (double*)malloc(size * sizeof(double));\n");
-        fprintf(self->dumper.out,"  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (rvalues).\\n\"); return 1; }");
+        fprintf(self->dumper.out,"  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }",a->name);
 
         icount=0;
         for (i=0; i<size-1; ++i) {
@@ -273,7 +273,7 @@ static void dump_values_attribute(grib_dumper* d, grib_accessor* a, const char*
         fprintf(self->dumper.out,"  free(rvalues); rvalues = NULL;\n");
         fprintf(self->dumper.out,"  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out,"  rvalues = (double*)malloc(size * sizeof(double));\n");
-        fprintf(self->dumper.out,"  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (rvalues).\\n\"); return 1; }");
+        fprintf(self->dumper.out,"  if (!rvalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }",a->name);
 
         icount=0;
         for (i=0; i<size-1; ++i) {
@@ -326,10 +326,12 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
     char* sval = NULL;
     grib_context* c=a->context;
     grib_handle* h=grib_handle_of_accessor(a);
+    int doing_unexpandedDescriptors=0;
 
     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 )
         return;
 
+    doing_unexpandedDescriptors = (strcmp(a->name, "unexpandedDescriptors")==0);
     grib_value_count(a,&count);
     size=count;
 
@@ -365,7 +367,7 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
         fprintf(self->dumper.out,"  free(ivalues); ivalues = NULL;\n\n");
         fprintf(self->dumper.out,"  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out,"  ivalues = (long*)malloc(size * sizeof(long));\n");
-        fprintf(self->dumper.out,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (ivalues).\\n\"); return 1; }");
+        fprintf(self->dumper.out,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }",a->name);
 
         icount=0;
         for (i=0;i<size-1;i++) {
@@ -380,20 +382,23 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
         fprintf(self->dumper.out,"\n");
         grib_context_free(a->context,values);
 
-        if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0)
+        if ((r=compute_bufr_key_rank(h,self->keys,a->name))!=0) {
             fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long_array(h, \"#%d#%s\", ivalues, size), 0);\n",r,a->name);
-        else
+        } else {
+            if (doing_unexpandedDescriptors) {
+                fprintf(self->dumper.out,"\n  /* Create the structure of the data section */\n");
+            }
             fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long_array(h, \"%s\", ivalues, size), 0);\n",a->name);
+            if (doing_unexpandedDescriptors) fprintf(self->dumper.out,"\n");
+        }
 
     } else {
-        int doing_unexpandedDescriptors=0;
         r=compute_bufr_key_rank(h,self->keys,a->name);
         sval=lval_to_string(c,value);
         if (r!=0) {
             fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long(h, \"#%d#%s\", ", r,a->name);
         } else {
-            if (strcmp(a->name, "unexpandedDescriptors")==0) {
-                doing_unexpandedDescriptors=1;
+            if (doing_unexpandedDescriptors) {
                 fprintf(self->dumper.out,"\n  /* Create the structure of the data section */\n");
             }
             fprintf(self->dumper.out,"  CODES_CHECK(codes_set_long(h, \"%s\", ", a->name);
@@ -401,8 +406,7 @@ static void dump_long(grib_dumper* d,grib_accessor* a, const char* comment)
 
         fprintf(self->dumper.out,"%s), 0);\n",sval);
         grib_context_free(c,sval);
-        if (doing_unexpandedDescriptors)
-            fprintf(self->dumper.out,"\n");
+        if (doing_unexpandedDescriptors) fprintf(self->dumper.out,"\n");
     }
 
     if (self->isLeaf==0) {
@@ -452,7 +456,7 @@ static void dump_long_attribute(grib_dumper* d, grib_accessor* a, const char* pr
         fprintf(self->dumper.out,"  free(ivalues); ivalues = NULL;\n");
         fprintf(self->dumper.out,"  size = %lu;\n", (unsigned long)size);
         fprintf(self->dumper.out,"  ivalues = (long*)malloc(size * sizeof(long));\n");
-        fprintf(self->dumper.out,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (ivalues).\\n\"); return 1; }");
+        fprintf(self->dumper.out,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }", a->name);
 
         icount=0;
         for (i=0;i<size-1;i++) {
@@ -558,7 +562,7 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     fprintf(self->dumper.out,"  free(svalues);\n");
     fprintf(self->dumper.out,"  size = %lu;\n", (unsigned long)size);
     fprintf(self->dumper.out,"  svalues = (char**)malloc(size * sizeof(char*));\n");
-    fprintf(self->dumper.out,"  if (!svalues) { fprintf(stderr, \"Failed to allocate memory (svalues).\\n\"); return 1; }\n");
+    fprintf(self->dumper.out,"  if (!svalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }\n",a->name);
 
     self->empty=0;
     values=(char**)grib_context_malloc_clear(c,size*sizeof(char*));
@@ -609,11 +613,21 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     int r;
     int err = _grib_get_string_length(a,&size);
     grib_handle* h=grib_handle_of_accessor(a);
+    const char* acc_name = a->name;
 
     if (size==0) return;
 
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0)
-        return;
+    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0 || (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY) != 0) {
+        /* ECC-356: Solution for the special local section key 'keyMore' and its alias 'ident' */
+        int skip = 1;
+        if ( (a->flags & GRIB_ACCESSOR_FLAG_HIDDEN)!=0 ) {
+            if ( strcmp(a->name, "keyMore")==0 && grib_is_defined(h, "ls.ident") ) {
+                skip = 0;
+                acc_name = "ident";
+            }
+        }
+        if (skip) return;
+    }
 
     value=(char*)grib_context_malloc_clear(c,size);
     if (!value) {
@@ -625,19 +639,20 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
     err = grib_unpack_string(a,value,&size);
     p=value;
-    r=compute_bufr_key_rank(h,self->keys,a->name);
+    r=compute_bufr_key_rank(h,self->keys,acc_name);
     if (grib_is_missing_string(a,(unsigned char *)value,size)) {
         strcpy(value, ""); /* Empty string means MISSING string */
     }
 
     while(*p) { if(!isprint(*p)) *p = '.'; p++; }
 
+    fprintf(self->dumper.out,"  size = %ld;\n", size);
     if (self->isLeaf==0) {
         depth+=2;
         if (r!=0)
-            fprintf(self->dumper.out,"  codes_set_string(h, \"#%d#%s\", ", r, a->name);
+            fprintf(self->dumper.out,"  codes_set_string(h, \"#%d#%s\", ", r, acc_name);
         else
-            fprintf(self->dumper.out,"  codes_set_string(h, \"%s\", ", a->name);
+            fprintf(self->dumper.out,"  codes_set_string(h, \"%s\", ", acc_name);
     }
     fprintf(self->dumper.out,"\"%s\", &size);\n",value);
 
@@ -646,10 +661,10 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
         int dofree=0;
 
         if (r!=0) {
-            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(a->name)+10));
+            prefix=(char*)grib_context_malloc_clear(c,sizeof(char)*(strlen(acc_name)+10));
             dofree=1;
-            sprintf(prefix,"#%d#%s",r,a->name);
-        } else prefix=(char*)a->name;
+            sprintf(prefix,"#%d#%s",r,acc_name);
+        } else prefix=(char*)acc_name;
 
         dump_attributes(d,a,prefix);
         if (dofree) grib_context_free(c,prefix);
@@ -680,7 +695,7 @@ static void _dump_long_array(grib_handle* h, FILE* f, const char* key, const cha
     fprintf(f,"  free(ivalues); ivalues = NULL;\n");
     fprintf(f,"  size = %lu;\n", (unsigned long)size);
     fprintf(f,"  ivalues = (long*)malloc(size * sizeof(long));\n");
-    fprintf(f,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (ivalues).\\n\"); return 1; }");
+    fprintf(f,"  if (!ivalues) { fprintf(stderr, \"Failed to allocate memory (%s).\\n\"); return 1; }",key);
 
     val=(long*)grib_context_malloc_clear(h->context,sizeof(long)*size);
     grib_get_long_array(h,key,val,&size);
@@ -818,7 +833,7 @@ static void footer(grib_dumper* d, grib_handle* h)
 
     /*fprintf(self->dumper.out,"  fout = fopen(\"outfile.bufr\", \"w\");");*/
     fprintf(self->dumper.out,"  if (!fout) {\n");
-    fprintf(self->dumper.out,"    fprintf(stderr, \"Failed to open (create) output file.\\n\");\n");
+    fprintf(self->dumper.out,"    fprintf(stderr, \"Failed to open (%s) output file.\\n\");\n", (d->count==1?"create":"append"));
     fprintf(self->dumper.out,"    return 1;\n");
     fprintf(self->dumper.out,"  }\n");
     fprintf(self->dumper.out,"  CODES_CHECK(codes_get_message(h,&buffer,&size),0);\n");
@@ -832,7 +847,8 @@ static void footer(grib_dumper* d, grib_handle* h)
     fprintf(self->dumper.out,"  }\n");
     fprintf(self->dumper.out,"  \n");
     fprintf(self->dumper.out,"  codes_handle_delete(h);\n");
-    fprintf(self->dumper.out,"  printf(\"Created output BUFR file 'outfile.bufr'.\\n\");\n");
+    if (d->count==1)
+        fprintf(self->dumper.out,"  printf(\"Created output BUFR file 'outfile.bufr'.\\n\");\n");
     fprintf(self->dumper.out,"  free(ivalues); ivalues = NULL;\n");
     fprintf(self->dumper.out,"  free(rvalues); rvalues = NULL;\n");
     fprintf(self->dumper.out,"  free(svalues); svalues = NULL;\n\n");
