@@ -813,6 +813,65 @@ void grib_skip_check(grib_runtime_options* options,grib_handle* h)
     }
 }
 
+/* See ECC-707 */
+static int fix_for_lsdate_needed(grib_handle* h)
+{
+    long lsdate_bug = 0;
+    int err = grib_get_long(h, "lsdate_bug", &lsdate_bug);
+    if (!err && lsdate_bug == 1) {
+        return 1;
+    }
+    return 0;
+}
+
+static int get_initial_element_of_array(grib_handle* h, const char* keyName, size_t num_vals, char* value)
+{
+    int err = 0, type = 0;
+    size_t len = num_vals;
+    char* sval = NULL;
+    unsigned char *uval = NULL;
+    long *lval = NULL;
+    double* dval = NULL;
+    grib_context* c = h->context;
+
+    Assert(num_vals > 1); /* This is for array keys */
+    if ((err = grib_get_native_type(h,keyName,&type))!=GRIB_SUCCESS) return err;
+    switch(type) {
+        case GRIB_TYPE_STRING:
+            grib_get_string_length(h,keyName,&len);
+            sval = (char*)grib_context_malloc(c,len*sizeof(char));
+            if (!sval) return GRIB_OUT_OF_MEMORY;
+            if((err = grib_get_string(h,keyName,sval,&len)) != GRIB_SUCCESS) return err;
+            sprintf(value, "%s", sval);
+            free(sval);
+            break;
+        case GRIB_TYPE_LONG:
+            lval = (long*)grib_context_malloc(c,num_vals*sizeof(long));
+            if (!lval) return GRIB_OUT_OF_MEMORY;
+            if((err = grib_get_long_array(h,keyName,lval,&len)) != GRIB_SUCCESS) return err;
+            sprintf(value, "%ld...", lval[0]);
+            free(lval);
+            break;
+        case GRIB_TYPE_DOUBLE:
+            dval = (double*)grib_context_malloc(c,num_vals*sizeof(double));
+            if (!dval) return GRIB_OUT_OF_MEMORY;
+            if((err = grib_get_double_array(h,keyName,dval,&len)) != GRIB_SUCCESS) return err;
+            sprintf(value, "%g...", dval[0]);
+            free(dval);
+            break;
+        case GRIB_TYPE_BYTES:
+            uval = (unsigned char*)grib_context_malloc(c,num_vals*sizeof(unsigned char));
+            if (!uval) return GRIB_OUT_OF_MEMORY;
+            if((err = grib_get_bytes(h,keyName,uval,&len)) != GRIB_SUCCESS) return err;
+            sprintf(value, "%d...", (short)uval[0]);
+            free(uval);
+            break;
+        default:
+            sprintf(value, "%s...", "");
+    }
+    return GRIB_SUCCESS;
+}
+
 void grib_print_key_values(grib_runtime_options* options, grib_handle* h)
 {
     int i=0;
@@ -821,9 +880,10 @@ void grib_print_key_values(grib_runtime_options* options, grib_handle* h)
     double dvalue=0;
     long lvalue=0;
     char value[MAX_STRING_LEN];
-    char* notfound="not_found";
+    const char* notfound="not_found";
     int written_to_dump = 0; /* boolean */
     grib_accessor* acc = NULL;
+    size_t num_vals = 0;
 
     if (!options->verbose) return;
 
@@ -864,15 +924,27 @@ void grib_print_key_values(grib_runtime_options* options, grib_handle* h)
             }
         } else {
             /* Other products e.g. GRIB */
+            const int fix_lsdate = (fix_for_lsdate_needed(h) && options->name_space && strcmp(options->name_space,"ls")==0);
+
             if (grib_is_missing(h,options->print_keys[i].name,&ret) && ret==GRIB_SUCCESS) {
                 sprintf(value,"MISSING");
             }
             else if ( ret == GRIB_SUCCESS ) {
+                const char* pName = NULL;
                 if (options->print_keys[i].type == GRIB_TYPE_UNDEFINED)
                     grib_get_native_type(h,options->print_keys[i].name,&(options->print_keys[i].type));
                 switch (options->print_keys[i].type) {
                 case GRIB_TYPE_STRING:
-                    ret=grib_get_string( h,options->print_keys[i].name,value,&len);
+                    pName = options->print_keys[i].name;
+                    if (fix_lsdate && strcmp(pName, "date")==0) { /* ECC-707 */
+                        pName = "ls.date";
+                    }
+                    ret = grib_get_size(h, pName, &num_vals);
+                    if(ret==GRIB_SUCCESS && num_vals>1) { /* See ECC-278 */
+                        ret = get_initial_element_of_array(h, pName, num_vals, value);
+                    } else {
+                        ret=grib_get_string( h,pName,value,&len);
+                    }
                     break;
                 case GRIB_TYPE_DOUBLE:
                     ret=grib_get_double( h,options->print_keys[i].name,&dvalue);
@@ -1094,3 +1166,15 @@ void grib_tools_write_message(grib_runtime_options* options, grib_handle* h)
 #endif
 
 }
+int exit_if_input_is_directory(const char* tool_name, const char* filename)
+{
+    struct stat s;
+    int stat_val = stat(filename, &s);
+    if ( stat_val == 0 ) {
+        if (S_ISDIR(s.st_mode)) {
+            fprintf(stderr, "%s: ERROR: \"%s\": Is a directory\n", tool_name, filename);
+            exit(1);
+        }
+    }
+    return 0;
+}
